pub enum LoadError {
NoImageLoaders,
NotSupported,
FormatNotSupported {
detected_format: Option<String>,
},
NoMatchingBytesLoader,
NoMatchingImageLoader {
detected_format: Option<String>,
},
NoMatchingTextureLoader,
Loading(String),
}Expand description
Represents a failed attempt at loading an image.
Variants
NoImageLoaders
Programmer error: There are no image loaders installed.
NotSupported
A specific loader does not support this scheme or protocol.
FormatNotSupported
A specific loader does not support the format of the image.
NoMatchingBytesLoader
Programmer error: Failed to find the bytes for this image because
there was no BytesLoader supporting the scheme.
NoMatchingImageLoader
Programmer error: Failed to parse the bytes as an image because
there was no ImageLoader supporting the format.
NoMatchingTextureLoader
Programmer error: no matching TextureLoader.
Because of the DefaultTextureLoader, this error should never happen.
Loading(String)
Runtime error: Loading was attempted, but failed (e.g. “File not found”).
Implementations