SizedTexture

Struct SizedTexture 

pub struct SizedTexture {
    pub id: TextureId,
    pub size: Vec2,
}
A texture with a known size.

Fields

id: TextureIdsize: Vec2

Point size of the original SVG, or the size of the image in texels.

Implementations

Source

impl SizedTexture

pub fn new(id: impl Into<TextureId>, size: impl Into<Vec2>) -> Self

Create a SizedTexture from a texture id with a specific size.

pub fn from_handle(handle: &TextureHandle) -> Self

Fetch the id and size from a TextureHandle.