pub struct InteractOptions {
pub move_to_top: bool,
}Expand description
How to handle multiple calls to crate::Response::interact and crate::Ui::interact_opt.
Fields
move_to_top: boolIf we call interact on the same widget multiple times, should we move it to the top on subsequent calls?