WidgetVisuals

Struct WidgetVisuals 

pub struct WidgetVisuals {
    pub bg_fill: Color32,
    pub weak_bg_fill: Color32,
    pub bg_stroke: Stroke,
    pub corner_radius: CornerRadius,
    pub fg_stroke: Stroke,
    pub expansion: f32,
}
bg = background, fg = foreground.

Fields

bg_fill: Color32

Background color of widgets that must have a background fill, such as the slider background, a checkbox background, or a radio button background.

Must never be Color32::TRANSPARENT.

weak_bg_fill: Color32

Background color of widgets that can optionally have a background fill, such as buttons.

May be Color32::TRANSPARENT.

bg_stroke: Stroke

For surrounding rectangle of things that need it, like buttons, the box of the checkbox, etc. Should maybe be called frame_stroke.

corner_radius: CornerRadius

Button frames etc.

fg_stroke: Stroke

Stroke and text color of the interactive part of a component (button text, slider grab, check-mark, …).

expansion: f32

Make the frame this much larger.

The problem with “expanding” widgets is that they now want to paint outside their own bounds, which then requires all parent UIs to have proper margins.

It also means hovered things are no longer properly aligned with every other widget.

Implementations

Source

impl WidgetVisuals

pub fn text_color(&self) -> Color32

pub fn rounding(&self) -> CornerRadius

👎Deprecated:

Renamed to corner_radius

Source

impl WidgetVisuals

pub fn ui(&mut self, ui: &mut Ui)