pub struct LayoutSection {
pub leading_space: f32,
pub byte_range: Range<ByteIndex>,
pub format: TextFormat,
}Expand description
A contiguous range of LayoutJob::text that shares the same TextFormat.
The sections of a LayoutJob are ordered and together cover the whole text
with no gaps and no overlaps. See LayoutJob::sections for the full invariant.
Text is shaped on a per-section basis: each section is an independent shaping run.
This means kerning (and ligatures) are only correct within a single section,
and not across the boundary between two adjacent sections.
For this reason LayoutJob::append merges consecutive sections when possible.
Fields
leading_space: f32Can be used for first row indentation.
byte_range: Range<ByteIndex>Range into LayoutJob::text.
format: TextFormatHow to format the text in this section (font, color, etc).