pub struct Checkbox<'a> { /* private fields */ }Expand description
Boolean on/off control with text label.
Usually you’d use Ui::checkbox instead.
// These are equivalent:
ui.checkbox(&mut my_bool, "Checked");
ui.add(egui::Checkbox::new(&mut my_bool, "Checked"));Implementations
Sourceimpl<'a> Checkbox<'a>
impl<'a> Checkbox<'a>
pub fn new(checked: &'a mut bool, atoms: impl IntoAtoms<'a>) -> Self
pub fn without_text(checked: &'a mut bool) -> Self
Sourcepub fn atoms(&self) -> &Atoms<'a>
pub fn atoms(&self) -> &Atoms<'a>
Output the checkbox’s Atoms.
This includes any images you have on the checkbox.
Sourcepub fn indeterminate(self, indeterminate: bool) -> Self
pub fn indeterminate(self, indeterminate: bool) -> Self
Display an indeterminate state (neither checked nor unchecked)
This only affects the checkbox’s appearance. It will still toggle its boolean value when clicked.