pub struct ImeComposition {
pub active_underline_stroke: Stroke,
pub inactive_underline_stroke: Stroke,
pub legacy_visuals: bool,
}Expand description
Visual style for IME composition.
Fields
active_underline_stroke: StrokeStroke used to underline the actively composed segment.
inactive_underline_stroke: StrokeStroke used to underline those non-active segments.
legacy_visuals: boolIf true, IME (Input Method Editor) composition (preedit) text is rendered
the legacy way: visually indistinguishable from a text selection, with the
cursor always shown at the end of the composition.
If false, egui renders proper IME composition visuals: the cursor position
inside the composition is shown, and the active conversion segment is
highlighted (using the strokes configured above) distinctly from the rest of the
composition. This makes composing Chinese, Japanese and Korean text much
clearer.
The legacy visuals have known shortcomings, but the new visuals are not yet
fully reliable on every platform either (e.g. winit reports an incorrect
cursor position for Korean IMEs on Windows), so this remains configurable.
Defaults to true on Windows (because of the aforementioned winit bug) and
to false everywhere else.
Implementations